import { VFXBatch, RenderMode } from './VFXBatch';
import { BufferGeometry, Layers, Material, Object3D } from 'three';
import { ParticleEmitter } from './ParticleEmitter';
import { IParticle } from './Particle';
export interface VFXBatchSettings {
    instancingGeometry: BufferGeometry;
    material: Material;
    uTileCount: number;
    vTileCount: number;
    renderMode: RenderMode;
    renderOrder: number;
    layers: Layers;
}
export interface SerializationOptions {
    useUrlForImage?: boolean;
}
export interface IParticleSystem {
    speedFactor: number;
    worldSpace: boolean;
    particleNum: number;
    particles: Array<IParticle>;
    emitter: ParticleEmitter<any>;
    _renderer?: BatchedRenderer;
    instancingGeometry: BufferGeometry;
    getRendererSettings(): VFXBatchSettings;
    paused: boolean;
    pause(): void;
    play(): void;
    restart(): void;
    clone(): IParticleSystem;
    toJSON(metaData: any, options: SerializationOptions): any;
}
export declare class BatchedRenderer extends Object3D {
    batches: Array<VFXBatch>;
    systemToBatchIndex: Map<IParticleSystem, number>;
    type: string;
    constructor();
    private static equals;
    addSystem(system: IParticleSystem): void;
    deleteSystem(system: IParticleSystem): void;
    updateSystem(system: IParticleSystem): void;
    update(delta: number): void;
}
